@@ -311,6 +311,8 @@ def connect(location):
     Connect to a Flame server on the given location, for instance localhost:9999 or ./u:unixsock
     This is just a convenience function to creates an appropriate Pyro proxy.
     """
+    if Pyro4.config.SERIALIZER != "pickle":
+        raise Pyro4.errors.ProtocolError("Flame requires the pickle serializer")
     proxy = Pyro4.core.Proxy("PYRO:%s@%s" % (Pyro4.constants.FLAME_NAME, location))
     proxy._pyroBind()
     return proxy
